LyricsFinder
============

LyricsFinder is a modular and easily expandable Python Package that is
used to extract lyrics. By having the ability to use a
combination of a Google Custom Search Engine and a set of extractors for
several sources, lyrics are attained with much higher accuracy and
generally from the best desired source.

Further reading:
https://lyricsfinder.giesela.io/
